@@ -68,10 +68,11 @@ def reVerSplitToPV(x):
             'PR':"",
             'PVR':""}.copy()
 
-def getPkgUses(fullpkg, version=None):
+def getPkgUses(fullpkg, version=None, prefix="/"):
     """Get USE and IUSE from package"""
     category,slash,pkg = fullpkg.partition('/')
-    pkgCategory = '/var/db/pkg/{0}'.format(category)
+    pkgCategory = 'var/db/pkg/{0}'.format(category)
+    pkgCategory = path.join(prefix, pkgCategory)
     if version is None:
         packages = filter(lambda x:x['PN'] == pkg,
                    map(reVerSplitToPV,
