@@ -412,14 +412,16 @@ class VariableClEmergeDefaultOpts(ReadonlyVariable):
     """
     EMERGE_DEFAULT_OPTS
     """
-    type = "list"
 
     def get(self):
         emergeInfo = self.Get('cl_emerge_info')
         for line in filter(lambda x:x.startswith("EMERGE_DEFAULT_OPTS="),
                            emergeInfo):
-            return filter(None,
-                          line.partition("=")[2].strip('\n"\'').split(' '))
+            key, op, value = line.partition('=')
+            for quote in ("'",'"'):
+                if value.startswith(quote):
+                    value = value[1:-1]
+            return value.replace(r'\"','"')
         return []
 
 class VariableClTemplatesLocate(Variable):
